#
# spec file for package rxp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 0
Name:           rxp
Version:        1.5.2
Release:        1.5
Summary:        XML Parser in C
License:        GPL-2.0-or-later
URL:            https://www.cogsci.ed.ac.uk/~richard/rxp.html
Source:         rxp-%{version}.tar.gz

%description
The current version of RXP supports XML 1.1, Namespaces 1.1, xml:id,
and XML Catalogs. To use an XML Catalog, set the environment variable
XML_CATALOG_FILES to a space-separated list of catalog files.

RXP was written by Richard Tobin at the Language Technology Group,
Human Communication Research Centre, University of Edinburgh.

A simple application (called rxp) is provided. It parses and writes XML
data, optionally expanding entities, defaulting attributes, and
translating to a different output encoding.

%package        devel
Summary:        Development files for %{name}
Conflicts:      festival-devel
Requires:       lib%{name}%{sover} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n lib%{name}%{sover}
Summary:        Shared library for %{name}

%description -n lib%{name}%{sover}
The current version of RXP supports XML 1.1, Namespaces 1.1, xml:id,
and XML Catalogs. To use an XML Catalog, set the environment variable
XML_CATALOG_FILES to a space-separated list of catalog files.

RXP was written by Richard Tobin at the Language Technology Group,
Human Communication Research Centre, University of Edinburgh.

A simple application (called rxp) is provided. It parses and writes XML
data, optionally expanding entities, defaulting attributes, and
translating to a different output encoding.

This package contains shared library

%prep
%autosetup -p1

%build
%configure \
  --enable-shared \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.a" -or -name "*.la" -delete -print

%ldconfig_scriptlets -n lib%{name}%{sover}

%files
%{_bindir}/rxp
%{_mandir}/man1/rxp.1%{?ext_man}

%files -n %{name}-devel
%license doc/COPYRIGHT doc/COPYING
%doc doc/Manual doc/Threads
%{_includedir}/%{name}*
%{_libdir}/*.so

%files -n lib%{name}%{sover}
%license doc/COPYRIGHT doc/COPYING
%{_libdir}/librxp.so.%{sover}*

%changelog
* Mon Mar  4 2024 Martin Pluskal <mpluskal@suse.com>
- Modernise package
- Split shared library into subpackage
- Add conflict with festival-devel for devel package
* Thu Feb 29 2024 jun wang <jgwang@suse.com>
- Update to 1.5.2
  * no changelog for 1.5.2
  * Drop rxp-1.4.8.diff as it is now in upstream
  * Add sub package rxp-devel
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Oct 15 2014 jengelh@inai.de
- Remove ancient specfile tags and sections
* Tue Jun 16 2009 coolo@novell.com
- fix build with glibc 2.10
* Tue Aug  7 2007 crrodriguez@suse.de
- update to version 1.4.8 with some bugfixes
- spec file cleanup
- make autobuild 100%% happy
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep  8 2005 ke@suse.de
- Remove executable bit from manpage.  Reported by Martin Lasarsch
  [#114849].
* Fri Apr 29 2005 ke@suse.de
- Update to 1.4.4.
* Thu Aug  5 2004 ke@suse.de
- Update to version 1.4.0:
  - Bug fixes (memory leaks etc.).
  - Fix namespace handling.
  - Speedup.
* Wed Feb 25 2004 hmacht@suse.de
- building as non-root
* Tue Jul  1 2003 coolo@suse.de
- don't use $RPM_PACKAGE_NAME
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Sep 29 2000 ke@suse.de
- Update to version 1.2.
- Use _mandir macro.
* Thu Feb 24 2000 ke@suse.de
- General spec file cleanup:
- Add group tag.
- Move manpage -> /usr/share.
- Move suse_chekc to the end of %%install.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jun 10 1999 ke@suse.de
- initial package: version 1.0.7
